
//////////////////////////////////////////////////////////////////////////////////
//EASTRISING TECHNOLOGY CO,.LTD.
//www.buydisplay.com
// Module    : ER-EPD3.97-1   800*480 dots
// Create    : JAVEN
// Date      : 2025-12-17
//               GND  GND
//               VCC  3.3V
//               SCLK PA5
//               MOSI PA7
//               RES  PD2
//               DC   PB5
//               CS   PA4
//               BUSY PB6

//******************************************************************************/


#include "delay.h"
#include "sys.h"
#include "epd.h"
#include "pic.h"

int main(void)
{
//    extern uint8_t ImageBW[ALLSCREEN_BYTES];
    delay_init();//延时函数初始化
    BSP_SPI_GPIOInit(); /* 初始化SPI总线 */
    EPD_Init();                 /* 初始化EPD */
    EPD_All_Fill(RED);        /* 全屏填充红色 */
    EPD_Update();               /* 更新显示 */
    EPD_Sleep();                /* 休眠EPD */
    delay_ms(1000);
    delay_ms(1000);
    delay_ms(1000);
    EPD_Init();                 /* 初始化EPD */
    EPD_All_Fill(YELLOW);        /* 全屏填充黄色 */
    EPD_Update();               /* 更新显示 */
    EPD_Sleep();                /* 休眠EPD */
    delay_ms(1000);
    delay_ms(1000);
    delay_ms(1000);
    EPD_Init();                 /* 初始化EPD */
    EPD_All_Fill(BLACK);        /* 全屏填充黑色 */
    EPD_Update();               /* 更新显示 */
    EPD_Sleep();                /* 休眠EPD */
    delay_ms(1000);
    delay_ms(1000);
    delay_ms(1000);
    while (1)
    {
        EPD_Init();                 /* 初始化EPD */
        EPD_All_Fill(WHITE);        /* 全屏填充白色 */
        EPD_DisplayImage(gImage_1); /* 发送图像数据 */
        EPD_Update();               /* 更新显示 */
        EPD_Sleep();                /* 休眠EPD */
        delay_ms(1000);
        delay_ms(1000);
        delay_ms(1000);

        EPD_Init();                           /* 初始化EPD */
        EPD_All_Fill(WHITE);                  /* 全屏填充白色 */
        EPD_Update();                         /* 更新显示 */
        EPD_Sleep();                          /* 休眠EPD */
        while (1)
        {
        }
    }
}



